@@ -654,7 +654,6 @@ static fmp4_log_level_t nxg_log_level_to_fmp4_log_level(ngx_http_request_t* r)
   case NGX_LOG_DEBUG:
     return FMP4_LOG_DEBUG;
   case NGX_LOG_NOTICE:
-    return FMP4_LOG_NOTICE_DO_NOT_USE;
   case NGX_LOG_INFO:
     return FMP4_LOG_INFO;
   case NGX_LOG_WARN:
@@ -667,7 +666,8 @@ static fmp4_log_level_t nxg_log_level_to_fmp4_log_level(ngx_http_request_t* r)
 }
 
 static void
-log_error_callback(void* context, fmp4_log_level_t level, char const* str)
+log_error_callback(void* context, fmp4_log_level_t level, char const* str,
+                   size_t size)
 {
   ngx_http_request_t* r = (ngx_http_request_t*)context;
 
@@ -681,9 +681,6 @@ log_error_callback(void* context, fmp4_log_level_t level, char const* str)
   case FMP4_LOG_INFO:
     log_level = NGX_LOG_INFO;
     break;
-  case FMP4_LOG_NOTICE_DO_NOT_USE:
-    log_level = NGX_LOG_NOTICE;
-    break;
   case FMP4_LOG_WARNING:
     log_level = NGX_LOG_WARN;
     break;
@@ -693,7 +690,7 @@ log_error_callback(void* context, fmp4_log_level_t level, char const* str)
     break;
    }
 
-  ngx_log_error(log_level, r->connection->log, 0, "fmp4: \"%s\"", str);
+  ngx_log_error(log_level, r->connection->log, 0, "fmp4: \"%*s\"", size, str);
 }
 
 static ngx_int_t
